%% This is file `compit.cls',
%%
%% Copyright 2005 Bastiaan N. Veelo, Bastiaan.N.Veelo@ntnu.no
%%
%% You hereby have permission to modify and distribute this file.
%% Please mention my name if you think that is appropriate.

%% This class mimics the MS Word template lay-out that is used for the
%% COMPIT conference proceedings.

\NeedsTeXFormat{LaTeX2e}[2001/06/01]
\ProvidesClass{nutts} [2008/06/26 v1.1 NuTTS style]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[a4paper,11pt,twoside]{article}

\RequirePackage{calc}
\RequirePackage[english]{babel}
\usepackage{amsfonts}
\usepackage{amssymb}
\usepackage{amsmath}
\RequirePackage{txfonts}
\RequirePackage{times}
\RequirePackage{fancyhdr}
\RequirePackage{ifthen}


%% Double spacing is old-fashioned (even in English) and most MS Word authors
%% do not use it either. You can forget about putting "\ " after every
%% abbreviation.
\frenchspacing


\setlength{\paperheight}{297mm} 
\setlength{\paperwidth} {210mm} 

\setlength{\textheight}{247mm}
\setlength{\textwidth}{160mm}

\setlength{\voffset}{0mm}
%\setlength{\topmargin}{-10.4mm}
\setlength{\topmargin}{0mm}
\setlength{\headheight}{0cm}
\setlength{\headsep}{0cm}

\setlength{\hoffset}{0mm}
\setlength{\oddsidemargin}{.5\paperwidth-.5\textwidth-1in} %-3.4mm
\setlength{\evensidemargin}{\paperwidth-\textwidth-\oddsidemargin-50.8mm} %2 inch

%\setlength{\parskip}{1ex plus0.5ex minus0.2ex} 


\pagestyle{empty}


\renewcommand{\maketitle}{%
  \begin{center}%
    {\Large\textbf{\@title}}\\[3mm]
    \@author
  \end{center}
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

%%
\def\3{\ss}
\def\hex{\char`\"}      % Ersatzdarstellung fuer "
\catcode`\"=\active     % " als aktives Zeichen
\def"{\accent'177}      % " als Accent definiert
%%

%%Markup section headings:

\renewcommand\section{\@startsection {section}{1}{\z@}%
                                     {-1.4ex \@plus .2ex}%
                                     {1.4ex }%
                                     {\normalfont\normalsize\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-1.4ex \@plus .2ex}%
                                     {.0005ex }%
                                     {\normalfont\normalsize\bfseries}}
\renewcommand\subsubsection{No subsubsections please!}

%%


%% Give captions a hanging margin (after article.cls):
\newlength{\capwidth}
\newlength{\caplabwidth}
\long\def\@makecaption#1#2{%
  \setlength{\capwidth}{\textwidth}
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1: #2}%
  \ifdim \wd\@tempboxa >\hsize
%    \settowidth{\caplabwidth}{#1: }%
%    \addtolength{\capwidth}{-\caplabwidth}%
%    #1: \parbox[t]{\capwidth}{#2}\par
    #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

%% Petite police pour figures / tableaux (pas bien cod)
\def\fnum@figure{Fig.\ \thefigure}
\def\fnum@table{Table \thetable}

%% Author - year citations without brackets
\renewcommand{\@cite}[2]{%
  {#1\ifthenelse{\boolean{@tempswa}}{,#2}{}}} 
\renewcommand{\@biblabel}[1]{}

\endinput
